GravityConfig class

Configuration class for gravity effects.

Constructors

GravityConfig({GravityType type = GravityType.none, double strength = 0.5, Offset direction = const Offset(0, 1), Offset center = Offset.zero})
Creates a GravityConfig with the specified parameters.
const

Properties

center → Offset
The center point coordinates for GravityType.point.
final
direction → Offset
The direction vector for GravityType.global.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strength → double
The intensity of the gravity force.
final
type → GravityType
The type of gravity effect to apply.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited