PerformanceMonitor class

Constructors

PerformanceMonitor()

Properties

averageFrameTime → Duration?
no setter
hashCode → int
The hash code for this object.
no setterinherited
recordedFrameCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
isDroppingFrames() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordFrameTime(Duration frameDuration) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited