TouchInteractionHandler class

Class that handles touch interactions with particles

Constructors

TouchInteractionHandler({required List<Particle> particles, required Offset? touchPoint, required double lineDistance, required Color touchColor, required Paint linePaint})

Properties

hashCode → int
The hash code for this object.
no setterinherited
lineDistance → double
final
linePaint → Paint
final
particles → List<Particle>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
test → int
final
touchColor → Color
final
touchPoint → Offset?
final

Methods

applyTouchPhysics(List<int> visibleParticles, AccelerationTracker tracker) → void
drawTouchLines(Canvas canvas, List<int> visibleParticles) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited