CompressedPath class

Represents a compressed path in the quadtree for optimization

Constructors

CompressedPath(List<Quadrant> path, int depth)
Creates a new CompressedPath with the given path and depth.
const

Properties

depth → int
The depth of this path in the quadtree structure.
final
hashCode → int
The hash code for this object.
no setterinherited
path → List<Quadrant>
The sequence of quadrants traversed to reach this path.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extend(Quadrant quad) → CompressedPath
Extends the path with a new quadrant
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited