QuadTreeParticle class

Represents a particle with index and 2D coordinates.

Constructors

QuadTreeParticle(int index, double x, double y)
Creates a QuadTreeParticle with the given index and coordinates (x, y).
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
Unique identifier or index of the particle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
The x-coordinate of the particle.
final
y → double
The y-coordinate of the particle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited