DistanceCalculator class
Constructors
- DistanceCalculator({int maxEntries = 10000})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxEntries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
betweenParticles(
Particle a, Particle b) → double -
betweenPoints(
Offset a, Offset b) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited